CONTRIBUTION GUIDE
==================

If you are planning to contribute to this project, kindly keep the pull request to the "develop" branch of the repositiory.

I would advice you to follow this git work-flow:

- Fork the repository and clone it to you system
- Create branch for the fix and checkout that branch.
- Update the code and check if everything is working.
- Commit with a clear message.
- Push the branch and keep pull request for that branch and the original "develop" branch.

From there Ill check it out and merge the code.

Thank you.

CONTRIBUTORS
============

Christopher Lσшƨσп (lowson.chris@gmail.com)
